@@ -1,7 +1,7 @@
 """Module for IQ option buyback resource."""
 
-from iqoptionapi.http.resource import Resource
-from iqoptionapi.http.billing import Billing
+from binarybotapi.http.resource import Resource
+from binarybotapi.http.billing import Billing
 
 
 class Buyback(Resource):
